using Microsoft.AspNetCore.Mvc;

namespace WebApplication10.Controllers;

[ApiController]
[Route("[controller]")]
public class BooksController: ControllerBase
{
    private readonly BookShelf _bookShelf;


    [HttpGet("books")]
    public IActionResult GetFilteredPageBooks([FromQuery] string author = "", [FromQuery] int page = 1,
        [FromQuery] int pageSize = 10)
    {
        if (page <= 0 || pageSize <= 0)
            return BadRequest("Page and pagesize must be greater than zero");
        var totalCount = _bookShelf.GetCount(author);
        var totalPages = (int)Math.Ceiling(totalCount / (double)pageSize);

        if (page > totalPages && (totalCount == 0 && page == 1))
            return BadRequest("Page number exceeds total pages.");

        var books = _bookShelf.GetBooks(author, page, pageSize);

        var result = new
        {
            TotalCount = totalCount,
            Page = page,
            PageSize = pageSize,
            Books = books
        };

        return Ok(result);
    }
    
    public BooksController(BookShelf bookShelf)
    {
        _bookShelf = bookShelf;
    }
    
    [HttpGet]
    [Route("all")]
    public IEnumerable<Book> GetAll()
    {
        return _bookShelf.GetAll();
    }

    [HttpPost]
    [Route("add")]
    public IActionResult Add([FromBody] Book book)
    {
        var newBook = _bookShelf.Add(book);
        return new OkObjectResult(newBook);
    }
    
    [HttpPut]
    [Route("update")]
    public IActionResult Update([FromBody] Book book)
    {
        var res = _bookShelf.Update(book);
        return res ? new OkResult() : new BadRequestResult();
    }
    
    [HttpDelete]
    [Route("delete/{id}")]
    public IActionResult Delete(int id)
    {
        _bookShelf.Delete(id);
        return new OkResult();
    }
}