const BookLibrary = (function () {

    // Получение списка книг и рендер

    function getAllBooksAndRender() {

        fetch('/books/all')

            .then(response => response.json())

            .then(data => {

                const targetElement = document.getElementById('booksList');

                // Очищаем содержимое элемента списка книг

                targetElement.innerHTML = '';



                data.forEach(book => {

                    renderBook(targetElement, book);

                });

            })

            .catch(error => {

                console.error('Error fetching books:', error);

            });

    }



    // Рендер отдельной книги

    function renderBook(targetElement, book) {

        // Общий контейнер для книги

        const bookContainer = document.createElement('div');

        bookContainer.classList.add('book-item');



        // Блок описания книги

        const descriptionBlock = document.createElement('div');

        descriptionBlock.classList.add('book-description');

        descriptionBlock.innerHTML = `

           <strong>Title:</strong> ${book.title}<br>

           <strong>Author:</strong> ${book.author}<br>

           <strong>ID:</strong> ${book.id}

       `;

        bookContainer.appendChild(descriptionBlock);



        // Блок кнопок

        const buttonsBlock = document.createElement('div');

        buttonsBlock.classList.add('book-buttons');



        // Редактировать

        const editButton = document.createElement('button');

        editButton.textContent = 'Edit';

        editButton.classList.add('edit-button');

        editButton.addEventListener('click', () => editBook(book));

        buttonsBlock.appendChild(editButton);



        // Удалить

        const deleteButton = document.createElement('button');

        deleteButton.textContent = 'Delete';

        deleteButton.classList.add('delete-button');

        deleteButton.addEventListener('click', () => deleteBook(book.id));

        buttonsBlock.appendChild(deleteButton);



        bookContainer.appendChild(buttonsBlock);

        targetElement.appendChild(bookContainer);

    }



    function deleteBook(bookId) {

        const apiUrl = `/books/delete/${bookId}`; // URL для удаления книги по ID



        fetch(apiUrl, {

            method: 'DELETE'

        })

            .then(response => {

                if (response.ok) {

                    alert(`Book with ID ${bookId} deleted successfully`);

                    // Обновляем список книг

                    getAllBooksAndRender();

                } else {

                    alert(`Failed to delete book with ID ${bookId}`);

                }

            })

            .catch(error => {

                console.error('Error deleting book:', error);

                alert(`Error deleting book with ID ${bookId}`);

            });

    }



    function editBook(book) {

        // Заполняем форму данными текущей книги

        document.getElementById('editTitle').value = book.title;

        document.getElementById('editAuthor').value = book.author;



        // Устанавливаем атрибут data-book-id на форму для хранения ID книги

        document.getElementById('editBookForm').setAttribute('data-book-id', book.id);



        // Открываем модальное окно

        document.getElementById('editBookModal').style.display = 'block';

    }



    function closeBookEdit() {

        document.getElementById('editBookModal').style.display = 'none';

    }



    function saveEditedBook() {

        // Получаем данные из формы

        const bookId = document.getElementById('editBookForm').getAttribute('data-book-id');

        const editedTitle = document.getElementById('editTitle').value;

        const editedAuthor = document.getElementById('editAuthor').value;



        // Отправляем данные на сервер (здесь пример с fetch)

        fetch(`/books/update`, {

            method: 'PUT',

            headers: {

                'Content-Type': 'application/json'

            },

            body: JSON.stringify({

                id: bookId,

                title: editedTitle,

                author: editedAuthor

            })

        })

            .then(response => {

                if (response.ok) {

                    alert(`Book with ID ${bookId} edited successfully`);

                    closeBookEdit(); // Закрываем модальное окно

                    getAllBooksAndRender(); // Обновляем список книг

                } else {

                    alert(`Failed to edit book with ID ${bookId}`);

                }

            })

            .catch(error => {

                console.error('Error editing book:', error);

                alert(`Error editing book with ID ${bookId}`);

            });

    }



    // Публичные методы

    return {
        GetAllBooksAndRender:  () => {
            getAllBooksAndRender();
        },
        RenderBook: (targetElement, book)=> {
            renderBook(targetElement, book)
        },
        CloseBookEdit: () => {
            closeBookEdit();
        },
        SaveEditedBook: () => {
            saveEditedBook();
        }
    };
})();